#!/usr/bin/env python3
"""
CS106AP Summer 2019
Lecture 11 example, written by Sonja Johnson-Yu,
Adapted from Nick Parlante's delcat
7.11.19
"""
import sys

PUNCTUATION = '!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~'

def delete_chars(s, chars):
    """
    Removes given characters from a string and returns the string.
    Function should work for words containing both upper and
    lowercase letters. The character string will always be lowercase.

    Input:
        s (string): string from which to remove characters
        chars (string): characters to be removed

    Returns:
        removed_string (string): string with characters removed

    >>> delete_chars('I love heating quesadillas', 'h')
    'I love eating quesadillas'
    >>> delete_chars('wAr and pEace', 'ae')
    'wr nd pc'
    >>> delete_chars('I **hate** punctuation!!!!', '!@#$%^&*.')
    'I hate punctuation'
    """
    result = ''
    for char in s:
        if char.lower() not in chars:
            result += char

    return result


def delete_words(s, words_to_delete):
    """
    Removes given words from a string and returns the string.

    Input:
        s (string): string from which to remove words
        words_to_delete (List[string]): words to be removed

    Returns:
        removed_string (string): string with words removed
    >>> delete_words('I like really really love noodles', ['like', 'really'])
    'I love noodles'
    >>> delete_words('I think bunnies are soo cute!', ['rabbit', 'bunny', 'bunnies'])
    'I think are soo cute!'
    >>> delete_words('Swimming is fun', ['shark', 'stingray'])
    'Swimming is fun'
    """
    result = ''
    words = s.split()
    for word in words:
        if word not in words_to_delete:
            result += word + ' '

    return result[:len(result) - 1]


def print_processed_text(filename, chars):  # can alternatively pass in words
    """
    Reads file and prints text with given characters removed.
    The first line should be printed without characters removed.

    Input:
        filename (string): file to be read
        chars (string): characters to be removed
    """
    first_line = True

    with open(filename, 'r') as f:
        for line in f:
            if first_line:
                print(line, end="")
                first_line = False
            else:
                print(delete_chars(line, chars), end="")
#                 print(delete_words(line, words))





def main():
    args = sys.argv[1:]
    # try this to see what "args" is for various command lines
    print('args:', args)
    # return

    # This program has 2 command line forms:
    # filename
    # e.g. python3 DeleteCharactersStarter.py poem.txt
    # -chars target filename
    # e.g. python3 DeleteCharactersStarter.py -chars aei poem.txt

    if len(args) == 1:
        # args[0] is filename
        print_processed_text(args[0], '')

    if len(args) == 3 and args[0] == '-chars':  # can alternatively use '-words'
        # words = args[1].split(',')
        # args[1] is chars, args[2] is filename
        print_processed_text(args[2], args[1])


# Python boilerplate.
if __name__ == '__main__':
    main()
